==> haskell-dense-linear-algebra-0.1.0.0-305-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dense-linear-algebra
version:              0.1.0.0
visibility:           public
id:                   dense-linear-algebra-0.1.0.0-KXbksPQEEBl1bEGHQOWLci
key:                  dense-linear-algebra-0.1.0.0-KXbksPQEEBl1bEGHQOWLci
license:              BSD-2-Clause
copyright:            2018 Author name here
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
synopsis:
    Simple and incomplete pure haskell implementation of linear algebra

description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.

category:             Math, Statistics, Numeric
abi:                  2d4645cbb5e4d3c05dc701b65ecc01ae
exposed:              True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/dense-linear-algebra-0.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dense-linear-algebra
hs-libraries:         HSdense-linear-algebra-0.1.0.0-KXbksPQEEBl1bEGHQOWLci
depends:
    base-4.16.4.0 deepseq-1.4.6.1
    math-functions-0.3.4.4-KdXfeaYEiEi8YvI3TVDP68
    primitive-0.7.4.0-AA8L6ftl9K2CnnGUysF0H7
    vector-0.13.1.0-IsxGr1wjc8yHuZdiqe6rZF
    vector-algorithms-0.9.0.2-9k5VmkFtQRTCWwBkHVGjYu
    vector-binary-instances-0.2.5.2-7goqWtXMbC795ioI9oThhe
    vector-th-unbox-0.2.2-KU03yd7LWsK5QjdTiFdKsV

haddock-interfaces:
    /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock

haddock-html:         /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dense-linear-algebra-0.1.0.0-306-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dense-linear-algebra
version:              0.1.0.0
visibility:           public
id:                   dense-linear-algebra-0.1.0.0-LMpN2uk0T1MLOWJ3A5lJOl
key:                  dense-linear-algebra-0.1.0.0-LMpN2uk0T1MLOWJ3A5lJOl
license:              BSD-2-Clause
copyright:            2018 Author name here
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
synopsis:
    Simple and incomplete pure haskell implementation of linear algebra

description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.

category:             Math, Statistics, Numeric
abi:                  fe43fe21117f100f6c53cc7df3527cd7
exposed:              True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/dense-linear-algebra-0.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dense-linear-algebra
hs-libraries:         HSdense-linear-algebra-0.1.0.0-LMpN2uk0T1MLOWJ3A5lJOl
depends:
    base-4.16.4.0 deepseq-1.4.6.1
    math-functions-0.3.4.4-6tyUiOgP4RAHTrB9uV65Jc
    primitive-0.7.4.0-2x9HuitYxlcInteNIbUTzK
    vector-0.13.1.0-HRMJcTNtHmH9PMIsGjP73X
    vector-algorithms-0.9.0.2-IlDfaN1LnLS9CyaBdM7Bl0
    vector-binary-instances-0.2.5.2-H5R4idgvlZTHvYw9sHhzPP
    vector-th-unbox-0.2.2-FFjYY8ktlP21kpX0GfhunZ

haddock-interfaces:
    /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock

haddock-html:         /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
